@@ -6,11 +6,11 @@ from django.db.models.base import ModelBase, Model
 from django.http import HttpResponse
 from django.template import RequestContext, loader
 
+from ..utils import UpdatedList
 from .paginator import Paginator
+from .response import SerializedHttpResponse
 from .serializer import json_dumps, xml_dumps
-from adrest.utils import UpdatedList
-from adrest.utils.status import HTTP_200_OK
-from adrest.utils.response import SerializedHttpResponse
+from .status import HTTP_200_OK
 
 
 class EmitterMeta(type):
