@@ -9,7 +9,7 @@ DATABASES =  {
                     'TEST_CHARSET': 'utf8',
                 }
             }
-INSTALLED_APPS = 'django.contrib.auth', 'django.contrib.contenttypes', 'adrest', 'tests.main', 'tests.simple'
+INSTALLED_APPS = 'django.contrib.auth', 'django.contrib.contenttypes', 'adrest', 'tests.main', 'tests.simple', 'tests.rpc'
 DEBUG = TEMPLATE_DEBUG = True
 CACHE_BACKEND = 'locmem://'
 ADREST_ACCESS_LOG = True
