@@ -6,5 +6,7 @@ class SimpleTestCase(AdrestTestCase):
     api = API
 
     def test_base(self):
+        uri = self.reverse('task')
+        self.assertEqual(uri, '/simple/task/')
         response = self.get_resource('task')
         self.assertContains(response, 'true')
